Update of /cvsroot/ufraw/ufraw
In directory vz-cvs-3.sog:/tmp/cvs-serv9542

Modified Files:
        ufraw_preview.c 
Log Message:
Reset crop data between image loading (in RC).


Index: ufraw_preview.c
===================================================================
RCS file: /cvsroot/ufraw/ufraw/ufraw_preview.c,v
retrieving revision 1.355
retrieving revision 1.356
diff -u -d -r1.355 -r1.356
--- ufraw_preview.c     20 Feb 2011 06:15:20 -0000      1.355
+++ ufraw_preview.c     12 Aug 2011 03:15:05 -0000      1.356
@@ -3453,12 +3453,14 @@
     gtk_dialog_response(dialog, GTK_RESPONSE_APPLY);
 }
 
 // Duplicate CFG into RC, except for ufobject which is copied elegantly
 static void copy_conf_to_rc(preview_data *data)
 {
     UFObject *tmp = RC->ufobject;
     *RC = *data->UF->conf;
     RC->ufobject = tmp;
+    conf_copy_transform(RC, &conf_default);
     UFObject *image = ufgroup_element(RC->ufobject, ufRawImage);
     ufobject_copy(image, data->UF->conf->ufobject);
 }


------------------------------------------------------------------------------
@@ -3453,12 +3453,14 @@
 }
 
-// Duplicate CFG into RC, except for ufobject which is copied elegantly
+// Duplicate CFG into RC, except for transform data, which is reset and
+// ufobject which is copied elegantly
 static void copy_conf_to_rc(preview_data *data)
 {
Get a FREE DOWNLOAD! and learn more about uberSVN rich system, 
user administration capabilities and model configuration. Take 
the hassle out of deploying and managing Subversion and the 
tools developers use with it. 
http://p.sf.net/sfu/wandisco-dev2dev
_______________________________________________
ufraw-cvs mailing list
ufraw-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/ufraw-cvs

Reply via email to